DPDispatcher API
===============

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. automodule:: dpdispatcher
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.JobStatus
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.base_context
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.dp_cloud_server
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.dp_cloud_server_context
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.dpdisp
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.lazy_local_context
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.local_context
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.lsf
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.machine
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.pbs
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.shell
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.slurm
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.ssh_context
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.submission
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.dpcloudserver
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.dpcloudserver.api
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.dpcloudserver.config
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.dpcloudserver.retcode
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.dpcloudserver.temp_test
   :members:
   :undoc-members:

.. automodule:: dpdispatcher.dpcloudserver.zip_file
   :members:
   :undoc-members:

